pub fn write_debug_artifact(filename: &str, contents: &str) -> Result<PathBuf>Expand description
Write debug artifact with restrictive permissions and return the file path.
Errors
Returns an error when the artifact directory or file cannot be created.