provider_from_name

Function provider_from_name 

pub fn provider_from_name(provider: &str) -> Result<Provider>
Parse a configured provider name into the canonical provider enum.

Errors

Returns an error when the provider name is not supported.