current_repo_root

Function current_repo_root 

pub fn current_repo_root() -> Result<PathBuf>
Get the repo root bound to the current task, falling back to the current directory.

Errors

Returns an error when the current directory cannot be resolved to a Git repository.