pub struct ParallelAnalyze { /* private fields */ }Expand description
Parallel analysis tool Spawns multiple subagents to analyze different aspects concurrently
Implementations
Sourceimpl ParallelAnalyze
impl ParallelAnalyze
Sourcepub fn new(provider: &str, model: &str, api_key: Option<&str>) -> Result<Self>
pub fn new(provider: &str, model: &str, api_key: Option<&str>) -> Result<Self>
Create a new parallel analyzer with default timeout
Errors
Returns an error when the requested provider runner cannot be created.
Sourcepub fn with_timeout(
provider: &str,
model: &str,
timeout_secs: u64,
api_key: Option<&str>,
additional_params: Option<HashMap<String, String>>,
) -> Result<Self>
pub fn with_timeout( provider: &str, model: &str, timeout_secs: u64, api_key: Option<&str>, additional_params: Option<HashMap<String, String>>, ) -> Result<Self>
Create a new parallel analyzer with custom timeout
Errors
Returns an error when the requested provider runner cannot be created.
Sourcepub fn with_limits(
provider: &str,
model: &str,
timeout_secs: u64,
max_turns: usize,
api_key: Option<&str>,
additional_params: Option<HashMap<String, String>>,
) -> Result<Self>
pub fn with_limits( provider: &str, model: &str, timeout_secs: u64, max_turns: usize, api_key: Option<&str>, additional_params: Option<HashMap<String, String>>, ) -> Result<Self>
Create a new parallel analyzer with custom timeout and turn budget. The turn budget is clamped to 1..=100.
Errors
Returns an error when the requested provider runner cannot be created.