pub struct RepoMapArgs {
pub token_budget: u32,
pub mentioned_files: Vec<PathBuf>,
pub max_files: usize,
}Fields
token_budget: u32mentioned_files: Vec<PathBuf>max_files: usizeTrait Implementations
Sourceimpl Clone for RepoMapArgs
impl Clone for RepoMapArgs
Sourcefn clone(&self) -> RepoMapArgs
fn clone(&self) -> RepoMapArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RepoMapArgs
impl Debug for RepoMapArgs
Sourceimpl<'de> Deserialize<'de> for RepoMapArgs
impl<'de> Deserialize<'de> for RepoMapArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RepoMapArgs
impl JsonSchema for RepoMapArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RepoMapArgs
impl RefUnwindSafe for RepoMapArgs
impl Send for RepoMapArgs
impl Sync for RepoMapArgs
impl Unpin for RepoMapArgs
impl UnsafeUnpin for RepoMapArgs
impl UnwindSafe for RepoMapArgs