pub struct StaticAnalysisArgs {
pub analyzer: StaticAnalyzer,
pub timeout_secs: u64,
pub max_output_chars: usize,
}Fields
analyzer: StaticAnalyzertimeout_secs: u64max_output_chars: usizeTrait Implementations
Sourceimpl Clone for StaticAnalysisArgs
impl Clone for StaticAnalysisArgs
Sourcefn clone(&self) -> StaticAnalysisArgs
fn clone(&self) -> StaticAnalysisArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StaticAnalysisArgs
impl Debug for StaticAnalysisArgs
Sourceimpl<'de> Deserialize<'de> for StaticAnalysisArgs
impl<'de> Deserialize<'de> for StaticAnalysisArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StaticAnalysisArgs
impl JsonSchema for StaticAnalysisArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StaticAnalysisArgs
impl RefUnwindSafe for StaticAnalysisArgs
impl Send for StaticAnalysisArgs
impl Sync for StaticAnalysisArgs
impl Unpin for StaticAnalysisArgs
impl UnsafeUnpin for StaticAnalysisArgs
impl UnwindSafe for StaticAnalysisArgs