Module cli

Module cli 

Structs

Cli
CLI structure defining the available commands and global arguments

Enums

Commands
Enumeration of available subcommands
GitHubReviewEvent
HookAction
Hook management sub-commands

Constants

LOG_FILE
Default log file path for debug output

Functions

handle_command
Handle the command based on parsed arguments
main
Main function to parse arguments and handle the command
parse_args
Parse the command-line arguments