pub fn handle_hook_command(action: &HookAction) -> Result<()>Expand description
Handle the hook command - install or uninstall the prepare-commit-msg hook
Errors
Returns an error when hook installation or removal fails.
pub fn handle_hook_command(action: &HookAction) -> Result<()>Handle the hook command - install or uninstall the prepare-commit-msg hook
Returns an error when hook installation or removal fails.