available_providers_parser

Function available_providers_parser 

pub fn available_providers_parser(s: &str) -> Result<String, String>
Validates that a provider name is available in the system

Errors

Returns an error string when the provider name is not supported.