pub struct CompanionStorage { /* private fields */ }Expand description
Storage backend for companion data
Implementations
Sourceimpl CompanionStorage
impl CompanionStorage
Sourcepub fn new(repo_path: &Path) -> Result<Self>
pub fn new(repo_path: &Path) -> Result<Self>
Create a new storage instance for the given repository
Errors
Returns an error when the companion storage directories cannot be created.
Sourcepub fn save_session(&self, session: &SessionState) -> Result<()>
pub fn save_session(&self, session: &SessionState) -> Result<()>
Sourcepub fn load_session(&self) -> Result<Option<SessionState>>
pub fn load_session(&self) -> Result<Option<SessionState>>
Load session state
Errors
Returns an error when the session file exists but cannot be read or parsed.
Sourcepub fn save_branch_memory(&self, memory: &BranchMemory) -> Result<()>
pub fn save_branch_memory(&self, memory: &BranchMemory) -> Result<()>
Sourcepub fn load_branch_memory(&self, branch: &str) -> Result<Option<BranchMemory>>
pub fn load_branch_memory(&self, branch: &str) -> Result<Option<BranchMemory>>
Load branch memory
Errors
Returns an error when the branch memory file exists but cannot be read or parsed.
Sourcepub fn list_branches(&self) -> Result<Vec<String>>
pub fn list_branches(&self) -> Result<Vec<String>>
List all branch memories for this repo
Errors
Returns an error when the branch memory directory cannot be read.
Sourcepub fn clear_session(&self) -> Result<()>
pub fn clear_session(&self) -> Result<()>