run_git_command

Function run_git_command 

pub fn run_git_command(args: &[&str]) -> Result<String>
Executes a git command and returns the output as a string

Arguments

  • args - The arguments to pass to git

Returns

A Result containing the output as a String or an error.

Errors

Returns an error when the Git command fails or emits invalid UTF-8 output.