Modules
- names
- String constants for the standard theme contract.
Structs
- Theme
Info - Metadata about a discoverable theme.
Enums
- Theme
Variant - Whether a theme is designed for dark or light backgrounds.
Functions
- current
- gradient_
string - Render a string with per-character gradient coloring as ANSI escape codes.
- list_
available_ themes - load_
theme - Load and activate a theme from an explicit file path.
- load_
theme_ by_ name - Load and activate a theme by name from the available theme directories.
- set_
theme