load_theme

Function load_theme 

pub fn load_theme(path: &Path) -> Result<(), OpalineError>
Load and activate a theme from an explicit file path.

Errors

Returns an error when the theme file cannot be read or parsed.