load_theme_by_name

Function load_theme_by_name 

pub fn load_theme_by_name(name: &str) -> Result<(), OpalineError>
Load and activate a theme by name from the available theme directories.

Errors

Returns an error when no theme with the given name can be found or loaded.