Module rgb

Module rgb 

RGB tuple accessors for use with the colored crate’s .truecolor() method. All colors resolve from the current theme at runtime.

Functions

accent_primary
Get primary accent color (Electric Purple) RGB from theme
accent_secondary
Get secondary accent color (Neon Cyan) RGB from theme
accent_tertiary
Get tertiary accent color (Coral) RGB from theme
error
Get error color (Error Red) RGB from theme
success
Get success color (Success Green) RGB from theme
text_dim
Get dim text color RGB from theme
text_muted
Get muted text color RGB from theme
text_primary
Get primary text color RGB from theme
text_secondary
Get secondary text color RGB from theme
warning
Get warning color (Electric Yellow) RGB from theme