Module theme

Module theme 

Modules

names
String constants for the standard theme contract.

Structs

ThemeInfo
Metadata about a discoverable theme.

Enums

ThemeVariant
Whether a theme is designed for dark or light backgrounds.

Functions

current
gradient_string
Render a string with per-character gradient coloring as ANSI escape codes.
list_available_themes
load_theme
Load and activate a theme from an explicit file path.
load_theme_by_name
Load and activate a theme by name from the available theme directories.
set_theme